Download PySNMP
===============

.. toctree::
   :maxdepth: 2

The PySNMP software is provided under terms and conditions of BSD-style 
license, and can be freely downloaded from 
`PyPI <http://pypi.python.org/pypi/pysnmp/>`_ or
GitHub (`master branch <https://github.com/lextudio/pysnmp/archive/master.zip>`_).


Besides official releases, it's advisable to try the cutting-edge
development code that could be taken from PySNMP
`source code repository <https://github.com/lextudio/pysnmp>`_.
It may be less stable in regards to general operation and changes to
public interfaces, but it's first to contain fixes to recently discovered bugs.

The best way to obtain PySNMP and dependencies is to run:

.. code-block:: bash

   $ pip install pysnmp

or

.. code-block:: bash

   $ easy_install pysnmp

In case of any issues, please open a `GitHub issue <https://github.com/lextudio/pysnmp/issues/new>`_ so we could try to help out.


